Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(923)

Unified Diff: content/browser/dom_storage/dom_storage_context_wrapper.h

Issue 1832813002: Add mojom module suffix in .mojom files in content. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Address Tom's comment Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/dom_storage/dom_storage_context_wrapper.h
diff --git a/content/browser/dom_storage/dom_storage_context_wrapper.h b/content/browser/dom_storage/dom_storage_context_wrapper.h
index 4de7f5f48dc6bce2b84519d83fdc5eb688c0d784..83b811dcb415223161de3bbf2b2fd3e3bfc42a2c 100644
--- a/content/browser/dom_storage/dom_storage_context_wrapper.h
+++ b/content/browser/dom_storage/dom_storage_context_wrapper.h
@@ -64,9 +64,9 @@ class CONTENT_EXPORT DOMStorageContextWrapper :
void Flush();
// See StoragePartitionService interface.
void OpenLocalStorage(const url::Origin& origin,
- LevelDBWrapperRequest request);
+ mojom::LevelDBWrapperRequest request);
private:
friend class DOMStorageMessageFilter; // for access to context()
« no previous file with comments | « chromecast/browser/cast_permission_manager.cc ('k') | content/browser/dom_storage/dom_storage_context_wrapper.cc » ('j') | no next file with comments »
@@ -64,9 +64,9 @@ class CONTENT_EXPORT DOMStorageContextWrapper :
void Flush();
- // See StoragePartitionService interface.
+ // See mojom::StoragePartitionService interface.
void OpenLocalStorage(const url::Origin& origin,

Powered by Google App Engine
This is Rietveld 408576698